==> eu-2.6.4.zip: eu/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '';
$GLOBALS['__l10n']['To menu'] = '';
$GLOBALS['__l10n']['To search'] = '';
$GLOBALS['__l10n']['By'] = 'Egilea:';
$GLOBALS['__l10n']['by'] = 'egilea:';
$GLOBALS['__l10n']['on'] = '';
$GLOBALS['__l10n']['On'] = '';
$GLOBALS['__l10n']['Continue reading'] = 'Jarraitu irakurketa';
$GLOBALS['__l10n']['no comment'] = 'iruzkinik ez ';
$GLOBALS['__l10n']['one comment'] = 'iruzkin 1 ';
$GLOBALS['__l10n']['%d comments'] = '%d iruzkin ';
$GLOBALS['__l10n']['no trackback'] = '';
$GLOBALS['__l10n']['one trackback'] = '';
$GLOBALS['__l10n']['%d trackbacks'] = '';
$GLOBALS['__l10n']['no attachment'] = 'eranskinik ez';
$GLOBALS['__l10n']['one attachment'] = 'eranskin 1';
$GLOBALS['__l10n']['%d attachments'] = '%d eranskin';
$GLOBALS['__l10n']['previous entries'] = 'Aurreko sarrerak ';
$GLOBALS['__l10n']['page'] = 'orrialdea';
$GLOBALS['__l10n']['of'] = '';
$GLOBALS['__l10n']['next entries'] = 'Hurrengo sarrerak';
$GLOBALS['__l10n']['Search'] = 'Bilatu ';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = 'webgunera ';
$GLOBALS['__l10n']['All keywords'] = '';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = '';
$GLOBALS['__l10n']['Categories'] = 'Atalak';
$GLOBALS['__l10n']['Subcategories'] = 'Atalak';
$GLOBALS['__l10n']['Archives'] = 'Artxiboak ';
$GLOBALS['__l10n']['Links'] = 'estekak ';
$GLOBALS['__l10n']['Subscribe'] = '';
$GLOBALS['__l10n']['Entries feed'] = '';
$GLOBALS['__l10n']['Comments feed'] = '';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['Attachments'] = 'Eranskinak ';
$GLOBALS['__l10n']['Permalink'] = 'Esteka iraunkorren';
$GLOBALS['__l10n']['Comments'] = 'Iruzkinak';
$GLOBALS['__l10n']['Your comment'] = 'Zure iruzkina ';
$GLOBALS['__l10n']['Your comment has been published.'] = '';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '';
$GLOBALS['__l10n']['Add a comment'] = '';
$GLOBALS['__l10n']['Name or nickname'] = '';
$GLOBALS['__l10n']['Email address'] = 'Helbide elektronikoa';
$GLOBALS['__l10n']['Website'] = 'Webgunea';
$GLOBALS['__l10n']['optional'] = 'hautazkoa';
$GLOBALS['__l10n']['Comment'] = 'Iruzkina';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Gogora nazazu ';
$GLOBALS['__l10n']['preview'] = 'aurreikusi';
$GLOBALS['__l10n']['send'] = 'bidali';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = 'Aipurako URLa ';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '';
$GLOBALS['__l10n']['Powered by %s'] = 'ek kudeatua';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = '';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '';
$GLOBALS['__l10n']['Password:'] = 'Pasahitza:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '';
$GLOBALS['__l10n']['Read'] = 'Irakurri';

==> eu-2.9.2.zip: eu/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = '';
$GLOBALS['__l10n']['To menu'] = '';
$GLOBALS['__l10n']['To search'] = '';
$GLOBALS['__l10n']['By'] = 'Egilea:';
$GLOBALS['__l10n']['by'] = 'egilea:';
$GLOBALS['__l10n']['on'] = '';
$GLOBALS['__l10n']['On'] = '';
$GLOBALS['__l10n']['Continue reading'] = 'Jarraitu irakurketa';
$GLOBALS['__l10n']['no comments'] = 'iruzkinik ez ';
$GLOBALS['__l10n']['one comment'] = 'iruzkin 1 ';
$GLOBALS['__l10n']['%d comments'] = '%d iruzkin ';
$GLOBALS['__l10n']['no trackbacks'] = '';
$GLOBALS['__l10n']['one trackback'] = '';
$GLOBALS['__l10n']['%d trackbacks'] = '';
$GLOBALS['__l10n']['no attachments'] = 'eranskinik ez';
$GLOBALS['__l10n']['one attachment'] = 'eranskin 1';
$GLOBALS['__l10n']['%d attachments'] = '%d eranskin';
$GLOBALS['__l10n']['previous entries'] = 'Aurreko sarrerak ';
$GLOBALS['__l10n']['page'] = 'orrialdea';
$GLOBALS['__l10n']['of'] = '';
$GLOBALS['__l10n']['next entries'] = 'Hurrengo sarrerak';
$GLOBALS['__l10n']['Search'] = 'Bilatu ';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = 'webgunera ';
$GLOBALS['__l10n']['All keywords'] = '';
$GLOBALS['__l10n']['Best of me'] = '';
$GLOBALS['__l10n']['Languages'] = '';
$GLOBALS['__l10n']['Categories'] = 'Atalak';
$GLOBALS['__l10n']['Subcategories'] = 'Atalak';
$GLOBALS['__l10n']['Archives'] = 'Artxiboak ';
$GLOBALS['__l10n']['Links'] = 'estekak ';
$GLOBALS['__l10n']['Subscribe'] = '';
$GLOBALS['__l10n']['Entries feed'] = '';
$GLOBALS['__l10n']['Comments feed'] = '';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['This post\'s comments feed'] = '';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Bidalketa honen iruzkinentzako RSS jarioa. ';
$GLOBALS['__l10n']['Attachments'] = 'Eranskinak ';
$GLOBALS['__l10n']['Permalink'] = 'Esteka iraunkorren';
$GLOBALS['__l10n']['Comments'] = 'Iruzkinak';
$GLOBALS['__l10n']['Your comment'] = 'Zure iruzkina ';
$GLOBALS['__l10n']['Your comment has been published.'] = '';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = '';
$GLOBALS['__l10n']['Add a comment'] = '';
$GLOBALS['__l10n']['Name or nickname'] = '';
$GLOBALS['__l10n']['Email address'] = 'Helbide elektronikoa';
$GLOBALS['__l10n']['Website'] = 'Webgunea';
$GLOBALS['__l10n']['optional'] = 'hautazkoa';
$GLOBALS['__l10n']['Comment'] = 'Iruzkina';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = '';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Gogora nazazu ';
$GLOBALS['__l10n']['preview'] = 'aurreikusi';
$GLOBALS['__l10n']['send'] = 'bidali';
$GLOBALS['__l10n']['They posted on the same topic'] = '';
$GLOBALS['__l10n']['Trackback URL'] = 'Aipurako URLa ';
$GLOBALS['__l10n']['You must provide an author name'] = '';
$GLOBALS['__l10n']['You must provide a comment'] = '';
$GLOBALS['__l10n']['Email address is not valid'] = '';
$GLOBALS['__l10n']['Document not found'] = '';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = '';
$GLOBALS['__l10n']['Powered by %s'] = 'ek kudeatua';
$GLOBALS['__l10n']['Subscribe to'] = '';
$GLOBALS['__l10n']['What is an RSS feed?'] = '';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = '';
$GLOBALS['__l10n']['Password needed'] = '';
$GLOBALS['__l10n']['You must give a password to access this area.'] = '';
$GLOBALS['__l10n']['Password:'] = 'Pasahitza:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = '';
$GLOBALS['__l10n']['Read'] = 'Irakurri';
